     /**
     * \brief JSON : Unit Test
   *
      * This unit test tests the toString() procedures of a JSON object and 
      * JSON array.  
      * 
   * \author Mihael Schmidt
   * \date   23.10.2011
   */

     H nomain

      *-------------------------------------------------------------------------
      * Prototypes
      *-------------------------------------------------------------------------
     D test_toStringComplex...
     D                 PR

      /copy RPGUNIT1,TESTCASE
      /copy 'json/json_h.rpgle'
      /copy 'message_h.rpgle'
      /copy 'libc_h.rpgle'


     /**
      * \brief 
      * 
      * This test tests the toString() procedures with a complex JSON object
      * including nested objects and arrays.
      * 
      * <p>
      * 
      * { "Product number" : 186189 ,
      *   "Product description": "After Eight 200gr" ,
      *   "In stock" : 52455 ; ' +
      *   "Distribution lock" : False ,
      *   "Cost" = 1.235 ,
      *   "Supplier" = 358 ,
      *   "Category" = { "Id" : 15 , "Description": "Sweets"},
      *   "Product line" : [
      *       {"Sweets" = "120.1.1." } ,
      *       {"Chocolate" = "120.1.2" } ] ,
      *   "Assigned stocks" = [ ] ,
      *   "Assigned display" = {}
      *   }
      *
      */ 
     P test_toStringComplex...
     P                 B                   export
      *
     D item            S               *
     D category        S               *
     D plids           S               *
     D plid            S               *
     D json_string     S          32000A   varying
     D ptr             S               *
     
   /free
       item = json_create();

       json_putInt(item : 'product_number' : 186189);
       json_putString(item : 'product_description' : 'After Eight 200gr');
       json_putInt(item : 'in_stock' : 52445);
       json_putBoolean(item : 'distribution_lock' : *off);
       json_util_putDecimal(item : 'cost' : 1.235 : 4);
       json_putInt(item : 'supplier' : 358);
       
       category = json_create();
       json_putInt(category : 'id' : 15);
       json_putString(category : 'description' : 'sweets');
       json_putObject(item : 'category' : category);
       
       plids = jsona_create();
       
       plid = json_create();
       json_putString(plid : 'Sweets' : '120.1.1.');
       jsona_putObject(plids : plid);
       plid = json_create();
       json_putString(plid : 'Chocolate' : '120.1.2.');
       jsona_putObject(plids : plid);
       
       json_putArray(item : 'product_lines' : plids);
       
       json_putArray(item : 'assigned_stocks' : jsona_create());
       
       json_putObject(item : 'assigned_display' : json_create());
       
       ptr = json_toString(item);
       
       json_string = ' {"product_number" : 186189 , "product_description" : ' + 
                      '"After Eight 200gr" , "in_stock" : 52445 , ' + 
                      '"distribution_lock" : false , "cost" : "1.2350" , ' + 
                      '"supplier" : 358 , "category" :  {"id" : 15 , ' + 
                      '"description" : "sweets" }  , "product_lines" :  ' + 
                      '[  {"Sweets" : "120.1.1." }  ,  {"Chocolate" : ' + 
                      '"120.1.2." }  ]  , "assigned_stocks" :  [  ]  , ' + 
                      '"assigned_display" :  { }  } ' + x'00';
       iEqual(strlen(%addr(json_string : *DATA)) : strlen(ptr));               
       iEqual(0 : strcmp(%addr(json_string : *DATA) : ptr));
       
       json_dispose(item);
   /end-free
     P                 E
